<?php

	lt_include( PLOG_CLASS_PATH."class/action/admin/adminaction.class.php" );
	lt_include( PLOG_CLASS_PATH."plugins/series/class/view/adminseriespluginsettingsview.class.php" );	
	lt_include( PLOG_CLASS_PATH."class/dao/blogs.class.php" );
	lt_include( PLOG_CLASS_PATH."class/dao/customfields/customfields.class.php" );
	lt_include( PLOG_CLASS_PATH."class/dao/customfields/customfield.class.php" );	

    class AdminSeriesPluginUpdateSettingsAction extends AdminAction 
	{
	
		var $_pluginEnabled;

    	/**
         * Constructor. If nothing else, it also has to call the constructor of the parent
         * class, BlogAction with the same parameters
         */
        function AdminSeriesPluginUpdateSettingsAction( $actionInfo, $request )
        {
        	$this->AdminAction( $actionInfo, $request );
            $this->requirePermission( "manage_plugins" );
        }
		
		function validate(){
            $this->_pluginEnabled = $this->_request->getValue( "pluginEnabled" );
            $this->_pluginEnabled = ($this->_pluginEnabled != "" );
			return true;
		}
		
		/**
		 * Updates the custom fields
		 */
		function _updateFields(){
			$customFields = new CustomFields();
			$blogFields = $customFields->getBlogCustomFields( $this->_blogInfo->getId());
			
                // if the checkbox fields doesn't exist and this plugin is enabled,
                // create the field
			if(!array_key_exists("seriesTitle", $blogFields) && $this->_pluginEnabled){
				$customField = new CustomField("seriesTitle", 
                                               $this->_locale->tr("plugin_series_title" ),
                                               CUSTOM_FIELD_TEXTBOX,
                                               $this->_blogInfo->getId(),
                                               false,
                                               true );
				$customFields->addCustomField($customField);
            }
            else{
				$protectedField = $blogFields["seriesTitle"];
				$protectedField->setHidden(!$this->_pluginEnabled);
				$customFields->updateCustomField($protectedField);
			}

			return true;
		}		

        /**
         * Carries out the specified action
         */
        function perform(){
        	// update the plugin configurations to blog setting
			$blogSettings = $this->_blogInfo->getSettings();
			$blogSettings->setValue( "plugin_series_enabled", $this->_pluginEnabled );
			$this->_blogInfo->setSettings( $blogSettings );
			
			// update the settings in the db, and make sure that everything went fine
			$blogs = new Blogs();
			if( !$blogs->updateBlog( $this->_blogInfo )) {
                $this->_view = new AdminSeriesPluginSettingsView( $this->_blogInfo );
                $this->_view->setErrorMessage( $this->_locale->tr("error_updating_settings"));
                $this->setCommonData();

                return false;   
			}
			
			// check if the fields already exist and if not, create them
            $this->_updateFields();
			
			// if everything went ok...
            $this->_blogInfo->setSettings( $blogSettings );
            $this->_session->setValue( "blogInfo", $this->_blogInfo );
            $this->saveSession();
			
			$this->_view = new AdminSeriesPluginSettingsView( $this->_blogInfo );
			$this->_view->setSuccessMessage( $this->_locale->tr("series_settings_saved_ok"));			
			$this->setCommonData();

			// clear the cache
			CacheControl::resetBlogCache( $this->_blogInfo->getId());			
            
            return true;
        }
    }
?>
